pub struct ExtensionHostManager { /* private fields */ }Implementations
Sourceimpl ExtensionHostManager
impl ExtensionHostManager
pub fn new(extension_id: String) -> Self
Sourcepub fn state(&self) -> ExtensionHostState
pub fn state(&self) -> ExtensionHostState
Returns the current state of the extension host process. Callers should use this instead of the removed is_running()/is_healthy() methods.
Sourcepub fn check_and_update_state(&mut self)
pub fn check_and_update_state(&mut self)
Checks if the child process is still alive and updates state accordingly. Call this before making decisions based on host state. This is the ONLY place where Running -> Unhealthy transition happens passively.
pub fn start( &mut self, extension_host_path: &str, outgoing_socket: &str, incoming_socket: &str, ) -> Result<(), String>
pub async fn restart_if_needed( &mut self, extension_host_path: &str, outgoing_socket: &str, incoming_socket: &str, ) -> Result<(), String>
pub fn stop(&mut self) -> Result<(), String>
pub fn shutdown(&mut self)